@@ -565,7 +565,7 @@ class PowerSupplyPU(_PSDev):
             SI_PING_H, SI_PING_V,
         )
 
-    _properties_timing = ('Delay-SP', 'Delay-RB')
+    _properties_timing = ('Delay-SP', 'Delay-RB', 'DelayRaw-SP', 'DelayRaw-RB')
 
     def __init__(self, devname):
         """."""
@@ -603,6 +603,16 @@ class PowerSupplyPU(_PSDev):
         """."""
         self._dev_timing['Delay-SP'] = value
 
+    @property
+    def delay_raw(self):
+        """."""
+        return self._dev_timing['DelayRaw-RB']
+
+    @delay_raw.setter
+    def delay_raw(self, value):
+        """."""
+        self._dev_timing['DelayRaw-SP'] = value
+
     @property
     def pulse(self):
         """."""
@@ -879,3 +889,4 @@ class PowerSupplyFC(_PSDev):
     def cmd_fofbacc_clear(self):
         """Command to clear FOFB accumulator."""
         self['FOFBAccClear-Cmd'] = 1
+        return True
