@@ -12,7 +12,7 @@ from ...bsmp import constants as _const_bsmp
 # version of the BSMP implementation of power supplies that is compatible
 # with the current implemenation of this module.
 
-__version__ = 'FRWM - V1.36 V0.41u - 09/04/2020'
+__version__ = 'FRWM - V1.40 V0.44 - 30/06/2022'
 
 # maximum number of power supplies controlled with a UDC
 UDC_MAX_NR_DEV = 4
@@ -175,9 +175,9 @@ class ConstPSBSMP:
     V_SCOPE_FREQUENCY = 25
     V_SCOPE_DURATION = 26
     V_SCOPE_SRC_DATA = 27
+    V_PERIOD_SYNC_PULSE = 28
 
     # --- undefined variables
-    V_UNDEF28 = 28
     V_UNDEF29 = 29
     V_UNDEF30 = 30
 
@@ -271,6 +271,7 @@ class ConstFBP(ConstPSBSMP):
     V_V_DCLINK = 35
     V_TEMP_SWITCHES = 36
     V_DUTY_CYCLE = 37  # (float)
+    V_PS_ALARMS = 38
     # --- FBP mirror variables ----
     V_PS_STATUS1 = 46
     V_PS_STATUS2 = 47
@@ -296,6 +297,10 @@ class ConstFBP(ConstPSBSMP):
     V_I_LOAD2 = 67
     V_I_LOAD3 = 68
     V_I_LOAD4 = 69
+    V_PS_ALARMS1 = 70
+    V_PS_ALARMS2 = 71
+    V_PS_ALARMS3 = 72
+    V_PS_ALARMS4 = 73
 
 
 class ConstFAC_DCDC(ConstPSBSMP):
@@ -324,6 +329,7 @@ class ConstFAC_DCDC(ConstPSBSMP):
     V_RH_IIB = 50
     V_IIB_INTERLOCKS = 51
     V_IIB_ALARMS = 52
+    V_PS_ALARMS = 53
 
 
 class ConstFAC_2P4S_DCDC(ConstPSBSMP):
@@ -381,6 +387,7 @@ class ConstFAC_2P4S_DCDC(ConstPSBSMP):
     V_RH_IIB_B = 79
     V_IIB_INTERLOCKS_B = 80
     V_IIB_ALARMS_B = 81
+    V_PS_ALARMS = 82
 
 
 class ConstFAC_2S_DCDC(ConstPSBSMP):
@@ -424,6 +431,7 @@ class ConstFAC_2S_DCDC(ConstPSBSMP):
     V_RH_IIB_2 = 65
     V_IIB_INTERLOCKS_2 = 66
     V_IIB_ALARMS_2 = 67
+    V_PS_ALARMS = 68
 
 
 class ConstFAP(ConstPSBSMP):
@@ -457,6 +465,7 @@ class ConstFAP(ConstPSBSMP):
     V_RH_IIB = 55
     V_IIB_INTERLOCKS = 56
     V_IIB_ALARMS = 57
+    V_PS_ALARMS = 58
 
 
 class ConstFAP_4P(ConstPSBSMP):
@@ -554,6 +563,7 @@ class ConstFAP_4P(ConstPSBSMP):
     V_RH_IIB_4 = 119
     V_IIB_INTERLOCKS_4 = 120
     V_IIB_ALARMS_4 = 121
+    V_PS_ALARMS = 122
 
 
 class ConstFAP_2P2S(ConstPSBSMP):
@@ -620,7 +630,7 @@ class ConstFAP_2P2S(ConstPSBSMP):
     V_I_DRIVER_2_IIB_2 = 88
     V_TEMP_INDUCTOR_IIB_2 = 89
     V_TEMP_HEATSINK_IIB_2 = 90
-    V_I_LEAKAGE_IIB_2 = 91
+    V_PS_ALARMS = 91
     V_TEMP_BOARD_IIB_2 = 92
     V_RH_IIB_2 = 93
     V_IIB_INTERLOCKS_2 = 94
