@@ -132,7 +132,7 @@ class Parameters(_Entity):
              'init': True, 'Op': False},
         51: {'count': 1, 'var_type': _Types.T_FLOAT, 'unit': '',
              'init': True, 'Op': False},
-          }
+    }
 
     def value_to_load(self, eid, value):
         """."""
@@ -197,11 +197,11 @@ class EntitiesPS(_Entities):
         {'eid': 25, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 26, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 27, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 28, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
         # --- undefined variables
-        {'eid': 28, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
         {'eid': 29, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
         {'eid': 30, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
-        )
+    )
 
     _ps_functions = (
         {'eid': _ConstPSBSMP.F_TURN_ON,
@@ -322,7 +322,8 @@ class EntitiesPS(_Entities):
         {'eid': _ConstPSBSMP.F_LOAD_DSP_MODULES_EEPROM,
          'i_type': (_Types.T_UINT16,), 'o_type': (_Types.T_UINT8,)},
         {'eid': _ConstPSBSMP.F_RESET_UDC,
-         'i_type': (), 'o_type': ()},)
+         'i_type': (), 'o_type': ()},
+    )
 
     _ps_curves = (
         {'eid': 0, 'waccess': True, 'count': 256,
@@ -330,7 +331,8 @@ class EntitiesPS(_Entities):
         {'eid': 1, 'waccess': True, 'count': 256,
          'nblocks': 16, 'var_type': _Types.T_FLOAT},
         {'eid': 2, 'waccess': False, 'count': 256,
-         'nblocks': 16, 'var_type': _Types.T_FLOAT},)
+         'nblocks': 16, 'var_type': _Types.T_FLOAT},
+    )
 
     _ps_parameters = Parameters()
 
@@ -360,8 +362,8 @@ class EntitiesFBP(EntitiesPS):
         {'eid': 35, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 36, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 37, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
+        {'eid': 38, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
         # --- undefined Variables
-        {'eid': 38, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
         {'eid': 39, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
         {'eid': 40, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
         {'eid': 41, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT8},
@@ -400,6 +402,11 @@ class EntitiesFBP(EntitiesPS):
         {'eid': 67, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 68, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 69, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
+        # ------ V_PS_ALARMS
+        {'eid': 70, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 71, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 72, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 73, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
     )
 
     _ps_curves = (
@@ -408,7 +415,8 @@ class EntitiesFBP(EntitiesPS):
         {'eid': 1, 'waccess': True, 'count': 256,
          'nblocks': 4, 'var_type': _Types.T_FLOAT},
         {'eid': 2, 'waccess': False, 'count': 256,
-         'nblocks': 4, 'var_type': _Types.T_FLOAT},)
+         'nblocks': 4, 'var_type': _Types.T_FLOAT},
+    )
 
 
 class EntitiesFAC_DCDC(EntitiesPS):
@@ -437,7 +445,9 @@ class EntitiesFAC_DCDC(EntitiesPS):
         {'eid': 49, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 50, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 51, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 52, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32})
+        {'eid': 52, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 53, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 class EntitiesFAC_2P4S_DCDC(EntitiesPS):
@@ -495,7 +505,9 @@ class EntitiesFAC_2P4S_DCDC(EntitiesPS):
         {'eid': 78, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 79, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 80, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 81, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},)
+        {'eid': 81, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 82, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 class EntitiesFAC_2S_DCDC(EntitiesPS):
@@ -539,7 +551,9 @@ class EntitiesFAC_2S_DCDC(EntitiesPS):
         {'eid': 64, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 65, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 66, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 67, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32})
+        {'eid': 67, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 68, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 class EntitiesFAP(EntitiesPS):
@@ -573,7 +587,9 @@ class EntitiesFAP(EntitiesPS):
         {'eid': 54, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 55, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 56, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 57, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32})
+        {'eid': 57, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 58, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 class EntitiesFAP_4P(EntitiesPS):
@@ -671,7 +687,9 @@ class EntitiesFAP_4P(EntitiesPS):
         {'eid': 118, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 119, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 120, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 121, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32})
+        {'eid': 121, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+        {'eid': 122, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 class EntitiesFAP_2P2S(EntitiesPS):
@@ -739,7 +757,7 @@ class EntitiesFAP_2P2S(EntitiesPS):
         {'eid': 88, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 89, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 90, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
-        {'eid': 91, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
+        {'eid': 91, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
         {'eid': 92, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 93, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 94, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
@@ -775,7 +793,8 @@ class EntitiesFAP_2P2S(EntitiesPS):
         {'eid': 124, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 125, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 126, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 127, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},)
+        {'eid': 127, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
 # --- Entities ACDC ---
@@ -831,7 +850,8 @@ class EntitiesFAC_2S_ACDC(EntitiesPS):
         {'eid': 55, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 56, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 57, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 58, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},)
+        {'eid': 58, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
     _ps_curves = ()
 
@@ -868,7 +888,8 @@ class EntitiesFAC_2P4S_ACDC(EntitiesPS):
         {'eid': 55, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 56, 'waccess': False, 'count': 1, 'var_type': _Types.T_FLOAT},
         {'eid': 57, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
-        {'eid': 58, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},)
+        {'eid': 58, 'waccess': False, 'count': 1, 'var_type': _Types.T_UINT32},
+    )
 
 
     _ps_curves = ()
