@@ -35,6 +35,8 @@ class _PSModel:
         'ScopeSrcAddr-RB': _c.V_SCOPE_SRC_DATA,
         'ScopeFreq-RB': _c.V_SCOPE_FREQUENCY,
         'ScopeDuration-RB': _c.V_SCOPE_DURATION,
+        # Trigger pulse diagnostics
+        'NrCtrlCycBtwLastTrigs-Mon': _c.V_PERIOD_SYNC_PULSE,
         }
     _e2r = {
         # Epics to BSMP variable but with pre/post-processing
@@ -306,16 +308,17 @@ class PSModelFBP(_PSModel):
     _e = _etity_psbsmp.EntitiesFBP
 
     _bsmp_variables = {
-        'IntlkSoft-Mon':  _const_psbsmp.ConstFBP.V_PS_SOFT_INTERLOCKS,
-        'IntlkHard-Mon':  _const_psbsmp.ConstFBP.V_PS_HARD_INTERLOCKS,
-        'WfmSyncPulseCount-Mon': _const_psbsmp.ConstFBP.V_COUNTER_SYNC_PULSE,
-        'Current-RB':  _const_psbsmp.ConstFBP.V_PS_SETPOINT,
-        'CurrentRef-Mon':  _const_psbsmp.ConstFBP.V_PS_REFERENCE,
-        'Current-Mon':  _const_psbsmp.ConstFBP.V_I_LOAD,
-        'LoadVoltage-Mon': _const_psbsmp.ConstFBP.V_V_LOAD,
-        'DCLinkVoltage-Mon': _const_psbsmp.ConstFBP.V_V_DCLINK,
-        'SwitchesTemperature-Mon': _const_psbsmp.ConstFBP.V_TEMP_SWITCHES,
-        'PWMDutyCycle-Mon': _const_psbsmp.ConstFBP.V_DUTY_CYCLE,
+        'IntlkSoft-Mon':  _c.V_PS_SOFT_INTERLOCKS,
+        'IntlkHard-Mon':  _c.V_PS_HARD_INTERLOCKS,
+        'WfmSyncPulseCount-Mon': _c.V_COUNTER_SYNC_PULSE,
+        'Current-RB':  _c.V_PS_SETPOINT,
+        'CurrentRef-Mon':  _c.V_PS_REFERENCE,
+        'Current-Mon':  _c.V_I_LOAD,
+        'LoadVoltage-Mon': _c.V_V_LOAD,
+        'DCLinkVoltage-Mon': _c.V_V_DCLINK,
+        'SwitchesTemperature-Mon': _c.V_TEMP_SWITCHES,
+        'PWMDutyCycle-Mon': _c.V_DUTY_CYCLE,
+        'Alarms-Mon': _c.V_PS_ALARMS,
     }
 
     _pruc_properties = {
@@ -338,14 +341,6 @@ class PSModelFBP(_PSModel):
             device_ids, epics_field, pru_controller, setpoints)
 
 
-class PSModelFBP_FOFB(_PSModel):
-    """FBP_FOFB power supply model."""
-
-    _n = 'FBP_FOFB'
-    _c = _const_psbsmp.ConstFBP
-    _e = _etity_psbsmp.EntitiesFBP
-
-
 class PSModelFAC_DCDC(_PSModel):
     """FAC power supply model."""
 
@@ -379,6 +374,7 @@ class PSModelFAC_DCDC(_PSModel):
         'RelativeHumidityIIB-Mon': _c.V_RH_IIB,
         'IntlkIIB-Mon': _c.V_IIB_INTERLOCKS,
         'AlarmsIIB-Mon': _c.V_IIB_ALARMS,
+        'Alarms-Mon': _c.V_PS_ALARMS,
     }
 
 
@@ -430,6 +426,7 @@ class PSModelFAC_2S_DCDC(_PSModel):
         'RelativeHumidityIIBMod2-Mon': _c.V_RH_IIB_2,
         'IntlkIIBMod2-Mon': _c.V_IIB_INTERLOCKS_2,
         'AlarmsIIBMod2-Mon': _c.V_IIB_ALARMS_2,
+        'Alarms-Mon': _c.V_PS_ALARMS,
         }
 
 
@@ -495,6 +492,7 @@ class PSModelFAC_2P4S_DCDC(PSModelFAC_DCDC):
         'RelativeHumidityIIBModB-Mon': _c.V_RH_IIB_B,
         'IntlkIIBModB-Mon': _c.V_IIB_INTERLOCKS_B,
         'AlarmsIIBModB-Mon': _c.V_IIB_ALARMS_B,
+        'Alarms-Mon': _c.V_PS_ALARMS,
         }
 
 
@@ -536,6 +534,7 @@ class PSModelFAP(_PSModel):
         'RelativeHumidityIIB-Mon': _c.V_RH_IIB,
         'IntlkIIB-Mon': _c.V_IIB_INTERLOCKS,
         'AlarmsIIB-Mon': _c.V_IIB_ALARMS,
+        'Alarms-Mon': _c.V_PS_ALARMS,
         }
 
 
@@ -641,6 +640,7 @@ class PSModelFAP_4P(_PSModel):
         'RelativeHumidityIIBMod4-Mon': _c.V_RH_IIB_4,
         'IntlkIIBMod4-Mon': _c.V_IIB_INTERLOCKS_4,
         'AlarmsIIBMod4-Mon': _c.V_IIB_ALARMS_4,
+        'Alarms-Mon': _c.V_PS_ALARMS,
         }
 
 
@@ -715,7 +715,6 @@ class PSModelFAP_2P2S(_PSModel):
         'IGBT2DriverCurrentIIBMod2-Mon': _c.V_I_DRIVER_2_IIB_2,
         'InductorTemperatureIIBMod2-Mon': _c.V_TEMP_INDUCTOR_IIB_2,
         'HeatSinkTemperatureIIBMod2-Mon': _c.V_TEMP_HEATSINK_IIB_2,
-        'LeakageCurrentIIBMod2-Mon': _c.V_I_LEAKAGE_IIB_2,
         'TemperatureIIBMod2-Mon': _c.V_TEMP_BOARD_IIB_2,
         'RelativeHumidityIIBMod2-Mon': _c.V_RH_IIB_2,
         'IntlkIIBMod2-Mon': _c.V_IIB_INTERLOCKS_2,
@@ -752,13 +751,10 @@ class PSModelFAP_2P2S(_PSModel):
         'RelativeHumidityIIBMod4-Mon': _c.V_RH_IIB_4,
         'IntlkIIBMod4-Mon': _c.V_IIB_INTERLOCKS_4,
         'AlarmsIIBMod4-Mon': _c.V_IIB_ALARMS_4,
+        'Alarms-Mon': _c.V_PS_ALARMS,
         }
 
 
-class PSModelCommercial(PSModelFAC_DCDC):
-    """Commercial power supply model."""
-
-
 # --- ACDC ---
 
 
@@ -933,7 +929,6 @@ class PSModelFactory:
     _psname_2_factory = {
         'FBP': PSModelFBP,
         'FBP_DCLink': PSModelFBP_DCLink,
-        'FBP_FOFB': PSModelFBP,
         'FAC_DCDC': PSModelFAC_DCDC,
         'FAC_2S_DCDC': PSModelFAC_2S_DCDC,
         'FAC_2S_ACDC': PSModelFAC_2S_ACDC,
@@ -942,7 +937,6 @@ class PSModelFactory:
         'FAP': PSModelFAP,
         'FAP_2P2S': PSModelFAP_2P2S,
         'FAP_4P': PSModelFAP_4P,
-        'Commercial': PSModelCommercial,
         }
 
     @staticmethod
