@@ -4,6 +4,7 @@ from .ps_search import PSSearch
 from .ma_search import MASearch
 from .bpms_search import BPMSearch
 from .id_search import IDSearch
+from .ioc_search import IOCSearch
 
 del hl_time_search
 del ll_time_search
@@ -11,3 +12,4 @@ del ps_search
 del ma_search
 del bpms_search
 del id_search
+del ioc_search
