@@ -32,29 +32,30 @@ class SOFB(_BaseClass):
         self._loop_state = self._csorb.LoopState.Open
         self._loop_freq = self._csorb.BPMsFreq
         self._loop_print_every_num_iter = 1000
+        self._loop_use_pssofb = False
         self._loop_max_orb_distortion = self._csorb.DEF_MAX_ORB_DISTORTION
         zer = _np.zeros(self._csorb.nr_corrs, dtype=float)
         self._pid_errs = [zer, zer.copy(), zer.copy()]
         self._pid_gains = dict(
-            ch=dict(kp=0.1, ki=2.0, kd=0.0),
-            cv=dict(kp=0.1, ki=2.0, kd=0.0),
-            rf=dict(kp=0.1, ki=2.0, kd=0.0))
+            ch=dict(kp=0.0, ki=0.5, kd=0.0),
+            cv=dict(kp=0.0, ki=0.5, kd=0.0),
+            rf=dict(kp=0.0, ki=0.5, kd=0.0))
         self._measuring_respmat = False
-        self._ring_extension = 1
         self._mancorr_gain = {'ch': 1.00, 'cv': 1.00}
         self._max_kick = {'ch': 300, 'cv': 300}
         self._max_delta_kick = {'ch': 5, 'cv': 5}
-        self._meas_respmat_kick = {'ch': 15, 'cv': 15}
+        self._meas_respmat_kick = {'ch': 15, 'cv': 22.5}
         if self.isring:
             self._mancorr_gain['rf'] = 1.00
             self._max_kick['rf'] = 1e12  # a very large value
             self._max_delta_kick['rf'] = 10
-            self._meas_respmat_kick['rf'] = 80
+            self._meas_respmat_kick['rf'] = 75
         if self.acc == 'SI':
             self.fofb = HLFOFB()
             self._download_fofb_kicks = False
-            self._download_fofb_kicks_perc = 0.0
+            self._download_fofb_kicks_perc = 0.01
             self._update_fofb_reforb = False
+            self._update_fofb_reforb_perc = 0.0
             self._donot_affect_fofb_bpms = False
             self._project_onto_fofb_nullspace = False
             self._drive_divisor = 12
@@ -114,11 +115,12 @@ class SOFB(_BaseClass):
             dbase['DeltaKickRF-SP'] = _part(
                 self.set_delta_kick, self._csorb.ApplyDelta.RF)
             dbase['MeasRespMatKickRF-SP'] = _part(self.set_respmat_kick, 'rf')
-            dbase['RingSize-SP'] = self.set_ring_extension
         if self.acc == 'SI':
+            dbase['CorrPSSOFBEnbl-Sel'] = self.set_use_pssofb
             dbase['FOFBDownloadKicksPerc-SP'] = self.set_fofb_download_perc
             dbase['FOFBDownloadKicks-Sel'] = _part(
                 self.set_fofb_interaction_props, 'downloadkicks')
+            dbase['FOFBUpdateRefOrbPerc-SP'] = self.set_fofb_updatereforb_perc
             dbase['FOFBUpdateRefOrb-Sel'] = _part(
                 self.set_fofb_interaction_props, 'updatereforb')
             dbase['FOFBNullSpaceProj-Sel'] = _part(
@@ -192,6 +194,25 @@ class SOFB(_BaseClass):
         else:
             _log.debug('process took {0:f}ms.'.format((tfin-time0)*1000))
 
+    def set_use_pssofb(self, val):
+        """Set whether or not closed loop will use PSSOFB.
+
+        Args:
+            val (bool): desired state.
+
+        Returns:
+            bool: Whether setting was successful.
+
+        """
+        if self._thread and self._thread.is_alive():
+            msg = 'ERR: Performing some task. Cannot change PSSOFB state!'
+            self._update_log(msg)
+            _log.error(msg[5:])
+            return False
+        self._loop_use_pssofb = bool(val)
+        self.run_callbacks('CorrPSSOFBEnbl-Sts', val)
+        return True
+
     def set_print_every_num_iters(self, value: float) -> bool:
         """Define number of iterations between loop statistics calculation.
 
@@ -246,27 +267,23 @@ class SOFB(_BaseClass):
         """
         value = min(max(value/100, 0), 1)
         self._download_fofb_kicks_perc = value
-        self.run_callbacks('FOFBDownloadKicksPerc-RB', value)
+        self.run_callbacks('FOFBDownloadKicksPerc-RB', value*100)
         return True
 
-    def set_ring_extension(self, val):
-        """."""
-        val = 1 if val < 1 else int(val)
-        val = self._csorb.MAX_RINGSZ if val > self._csorb.MAX_RINGSZ else val
-        if val == self._ring_extension:
-            return True
-        okay = self.orbit.set_ring_extension(val)
-        if not okay:
-            return False
-        okay &= self.matrix.set_ring_extension(val)
-        if not okay:
-            return False
-        self._ring_extension = val
-        self.run_callbacks('RingSize-RB', val)
-        bpms = _np.array(self._csorb.bpm_pos)
-        bpm_pos = [bpms + i*self._csorb.circum for i in range(val)]
-        bpm_pos = _np.hstack(bpm_pos)
-        self.run_callbacks('BPMPosS-Mon', bpm_pos)
+    def set_fofb_updatereforb_perc(self, value: float):
+        """Set percentage of reference orbit update in FOFB.
+
+        Args:
+            value (float): percentage of calculated orbit.
+                Must be in [-100, 100].
+
+        Returns:
+            bool: Whether property was set.
+
+        """
+        value = min(max(value/100, -1), 1)
+        self._update_fofb_reforb_perc = value
+        self.run_callbacks('FOFBUpdateRefOrbPerc-RB', value*100)
         return True
 
     def apply_corr(self, code):
@@ -277,11 +294,6 @@ class SOFB(_BaseClass):
             _log.error(msg[5:])
             return False
 
-        if self.orbit.mode == self._csorb.SOFBMode.Offline:
-            msg = 'ERR: Offline, cannot apply kicks.'
-            self._update_log(msg)
-            _log.error(msg[5:])
-            return False
         if self._thread and self._thread.is_alive():
             msg = 'ERR: Loop is Closed or MeasRespMat is On.'
             self._update_log(msg)
@@ -634,11 +646,6 @@ class SOFB(_BaseClass):
         return True
 
     def _start_meas_respmat(self):
-        if self.orbit.mode == self._csorb.SOFBMode.Offline:
-            msg = 'ERR: Cannot Meas Respmat in Offline Mode'
-            self._update_log(msg)
-            _log.error(msg[5:])
-            return False
         if self._measuring_respmat:
             msg = 'ERR: Measurement already in process.'
             self._update_log(msg)
@@ -808,8 +815,25 @@ class SOFB(_BaseClass):
             refx0 = fofb.refx
             refy0 = fofb.refy
 
-        wait_orb_error = int(5)
-        previous_orb_problem = False
+        if self._loop_use_pssofb:
+            msg = 'Turning on PSSOFB...'
+            self._update_log(msg)
+            _log.info(msg)
+            self.correctors.use_pssofb = True
+            msg = 'PSSOFB ready!'
+            self._update_log(msg)
+            _log.info(msg)
+
+            if self.correctors.sync_kicks != self._csorb.CorrSync.Off:
+                msg = 'Setting Trigger to listen to EVG Clock...'
+                self._update_log(msg)
+                _log.info(msg)
+                self.run_callbacks('CorrSync-Sts', self._csorb.CorrSync.Clock)
+                self.correctors.set_corrs_mode(self._csorb.CorrSync.Clock)
+                msg = 'Trigger ready!'
+                self._update_log(msg)
+                _log.info(msg)
+
         tims = []
         while self._loop_state == self._csorb.LoopState.Closed:
             if not self.havebeam:
@@ -817,9 +841,9 @@ class SOFB(_BaseClass):
                 self._update_log(msg)
                 _log.info(msg)
                 break
-            iter = len(times)
-            self.run_callbacks('LoopNumIters-Mon', iter)
-            if iter >= self._loop_print_every_num_iter:
+            itern = len(times)
+            self.run_callbacks('LoopNumIters-Mon', itern)
+            if itern >= self._loop_print_every_num_iter:
                 _Thread(
                     target=self._print_auto_corr_info,
                     args=(times, rets, _time()-tim0), daemon=True).start()
@@ -864,33 +888,9 @@ class SOFB(_BaseClass):
             tims.append(_time())
 
             if not self._check_valid_orbit(orb):
-                # NOTE: The code bellow is the default implementation.
-                #       We decided to use the temporaty work around solution
-                #       implemented above to handle mal-functioning BPMs.
-                # self._loop_state = self._csorb.LoopState.Open
-                # self.run_callbacks('LoopState-Sel', 0)
-                # break
-
-                self.run_callbacks('LoopState-Sts', 0)
-                msg = 'WARN: Skipping iteration.'
-                self._update_log(msg)
-                _log.info(msg)
-                for ii_ in range(wait_orb_error):
-                    msg = f'WARN: waiting {wait_orb_error-ii_:d}s ...'
-                    self._update_log(msg)
-                    _log.info(msg)
-                    _sleep(1)
-                msg = f'WARN: Trying again...'
-                self._update_log(msg)
-                _log.info(msg)
-                previous_orb_problem = True
-                continue
-            elif previous_orb_problem:
-                msg = f'WARN: Orbit is Ok now. Resuming correction...'
-                self._update_log(msg)
-                _log.info(msg)
-                previous_orb_problem = False
-                self.run_callbacks('LoopState-Sts', 1)
+                self._loop_state = self._csorb.LoopState.Open
+                self.run_callbacks('LoopState-Sel', 0)
+                break
 
             dkicks = self._process_pid(dkicks, interval)
 
@@ -924,6 +924,25 @@ class SOFB(_BaseClass):
                 # skip this iteration
                 continue
 
+        if self._loop_use_pssofb:
+            msg = 'Turning off PSSOFB...'
+            self._update_log(msg)
+            _log.info(msg)
+            self.correctors.use_pssofb = False
+            msg = 'PSSOFB is off!'
+            self._update_log(msg)
+            _log.info(msg)
+
+            if self.correctors.sync_kicks != self._csorb.CorrSync.Off:
+                msg = 'Setting Trigger to listen to Event...'
+                self._update_log(msg)
+                _log.info(msg)
+                self.run_callbacks('CorrSync-Sts', self._csorb.CorrSync.Event)
+                self.correctors.set_corrs_mode(self._csorb.CorrSync.Event)
+                msg = 'Trigger ready!'
+                self._update_log(msg)
+                _log.info(msg)
+
         msg = 'Loop opened!'
         self._update_log(msg)
         _log.info(msg)
@@ -1052,7 +1071,8 @@ class SOFB(_BaseClass):
 
         if self._update_fofb_reforb and fofb.loop_state:
             dorb = self.matrix.estimate_orbit_variation(dkicks)
-            # According to my understanding of SOLEIL's paper on this
+            dorb *= self._update_fofb_reforb_perc
+            # NOTE: According to my understanding of SOLEIL's paper on this
             # subject:
             # https://accelconf.web.cern.ch/d09/papers/mooc01.pdf
             # https://accelconf.web.cern.ch/d09/talks/mooc01_talk.pdf
@@ -1065,7 +1085,13 @@ class SOFB(_BaseClass):
             fofb.cmd_fofbctrl_syncreforb()
 
         if self._download_fofb_kicks and fofb.loop_state:
-            kicks_fofb = _np.r_[fofb.kickch, fofb.kickcv, 0]
+            # NOTE: Do not download kicks from correctors not in the loop:
+            kickch = fofb.kickch.copy()
+            kickcv = fofb.kickcv.copy()
+            kickch[~fofb.chenbl] = 0
+            kickcv[~fofb.cvenbl] = 0
+
+            kicks_fofb = _np.r_[kickch, kickcv, 0]
             dorb = _np.dot(fofb.respmat, kicks_fofb)
             # NOTE: calc_kicks return the kicks to correct dorb, which means
             # that a minus sign is already applied by this method. To negate
@@ -1074,7 +1100,7 @@ class SOFB(_BaseClass):
             dkicks2 *= -self._download_fofb_kicks_perc
 
             kicks, dkicks2 = self._process_kicks(
-                self._ref_corr_kicks+dkicks, dkicks2, apply_gain=False)
+                self._ref_corr_kicks, dkicks + dkicks2, apply_gain=False)
         return kicks
 
     def _calc_correction(self):
